//
//  ViewController.m
//  mapView
//
//  Created by Marco Cota on 24/11/2014.
//  Copyright (c) 2014 Appcelerator Support. All rights reserved.
//

#import "ViewController.h"
@import CoreLocation;

@interface ViewController ()<CLLocationManagerDelegate>
@property (strong, nonatomic) CLLocationManager *locationManager;

@end

@implementation ViewController
@synthesize ampView;

- (void)viewDidLoad {
    [super viewDidLoad];

    self.locationManager = [[CLLocationManager alloc] init];
    self.locationManager.delegate = self;
    
    // Check for iOS 8. Without this guard the code will crash with "unknown selector" on iOS 7.
    if ([self.locationManager respondsToSelector:@selector(requestWhenInUseAuthorization)]) {
        [self.locationManager requestWhenInUseAuthorization];
    }
    
    self.ampView.delegate = self;
    self.ampView.showsUserLocation = YES;
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (void)mapView:(MKMapView *)mapView didUpdateUserLocation:(MKUserLocation *)userLocation
{
    MKCoordinateRegion region = MKCoordinateRegionMakeWithDistance(CLLocationCoordinate2DMake(37.3331998, -122.0376877), 800, 800);
    [self.ampView setRegion:[self.ampView regionThatFits:region] animated:YES];
    
    // Add an annotation
    MKPointAnnotation *point = [[MKPointAnnotation alloc] init];
    point.coordinate = CLLocationCoordinate2DMake(37.3313429,-122.0357358);
    point.title = @"Extra";
    point.subtitle = @"I'm here!!!";
    
    [self.ampView addAnnotation:point];
    
    // Add an annotation
    MKPointAnnotation *point2 = [[MKPointAnnotation alloc] init];
    point2.coordinate = CLLocationCoordinate2DMake(37.331532, -122.032731);
    point2.title = @"No Extra";
    point2.subtitle = @"I'm not here!!!";
    
    [self.ampView addAnnotation:point2];
    
    // Add an annotation
    MKPointAnnotation *point3 = [[MKPointAnnotation alloc] init];
    point3.coordinate = CLLocationCoordinate2DMake(37.3331998, -122.0376877);
    point3.title = @"Extra";
    point3.subtitle = @"I'm here!!!";
    
    [self.ampView addAnnotation:point3];
}

- (MKAnnotationView *)mapView:(MKMapView *)mapView viewForAnnotation:(id <MKAnnotation>)annotation
{
    NSLog(@"viewForAnotation");
    // If it's the user location, just return nil.
    if ([annotation isKindOfClass:[MKUserLocation class]])
        return nil;
    
    // Handle any custom annotations.
    if ([annotation isKindOfClass:[MKPointAnnotation class]])
    {
        // Try to dequeue an existing pin view first.
        MKAnnotationView *pinView = (MKAnnotationView*)[mapView dequeueReusableAnnotationViewWithIdentifier:@"CustomPinAnnotationView"];
        if (!pinView)
        {
            // If an existing pin view was not available, create one.
            pinView = [[MKAnnotationView alloc] initWithAnnotation:annotation reuseIdentifier:@"CustomPinAnnotationView"];
            pinView.canShowCallout = YES;
            pinView.image = [UIImage imageNamed:@"appc.png"];
            pinView.calloutOffset = CGPointMake(0, 32);
            
            if([annotation.title  isEqual: @"Extra"])
            {
                NSLog(@"Extra");
                // Add a detail disclosure button to the callout.
                UIButton* rightButton = [UIButton buttonWithType:UIButtonTypeDetailDisclosure];
                pinView.rightCalloutAccessoryView = rightButton;
                
                // Add an image to the left callout.
                UIImageView *iconView = [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"appc.png"]];
                pinView.leftCalloutAccessoryView = iconView;
            }
        } else {
            pinView.annotation = annotation;
        }
        return pinView;
    }
    return nil;
}

// Location Manager Delegate Methods
- (void)locationManager:(CLLocationManager *)manager didUpdateLocations:(NSArray *)locations
{
    NSLog(@"%@", [locations lastObject]);
}



@end
